# Generated by Django 2.2.28 on 2022-12-23 12:37

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('minidebconf', '0002_auto_20221009_2000'),
    ]

    operations = [
        migrations.CreateModel(
            name='RegistrationType',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('description', models.CharField(max_length=64, verbose_name='Description')),
            ],
        ),
        migrations.AddField(
            model_name='registration',
            name='phone_number',
            field=models.CharField(blank=True, max_length=24, null=True),
        ),
        migrations.AddField(
            model_name='registration',
            name='registration_type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.PROTECT, to='minidebconf.RegistrationType'),
        ),
    ]
