# Generated by Django 4.2.8 on 2023-12-23 20:15

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("minidebconf", "0005_registration_arranged_accommodation_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="registration",
            name="notes",
            field=models.TextField(blank=True, null=True, verbose_name="Notes"),
        ),
        migrations.AddField(
            model_name="registration",
            name="travel_cost",
            field=models.IntegerField(
                default=None, null=True, blank=True, verbose_name="Travel costs"
            ),
        ),
        migrations.AddField(
            model_name="registration",
            name="travel_reimbursement",
            field=models.BooleanField(
                default=False, verbose_name="Reimburse travel costs"
            ),
        ),
    ]
