# -*- coding: utf-8 -*-
# Generated by Django 1.11.18 on 2019-03-09 01:44
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('register', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='ChildCare',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('needs', models.TextField(blank=True)),
                ('details', models.TextField(blank=True)),
                ('attendee', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='child_care', to='register.Attendee')),
            ],
        ),
        migrations.RemoveField(
            model_name='accomm',
            name='childcare',
        ),
        migrations.RemoveField(
            model_name='accomm',
            name='childcare_details',
        ),
        migrations.RemoveField(
            model_name='accomm',
            name='childcare_needs',
        ),
    ]
