# -*- coding: utf-8 -*-
# Generated by Django 1.11.18 on 2019-07-26 19:46
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('volunteers', '0001_initial'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='volunteer',
            name='tasks',
        ),
        migrations.AlterField(
            model_name='task',
            name='volunteers',
            field=models.ManyToManyField(blank=True, related_name='tasks', to='volunteers.Volunteer'),
        ),
    ]
