# Generated by Django 2.2.27 on 2022-07-16 21:33

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('front_desk', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='checkin',
            name='meal_vouchers',
            field=models.BooleanField(default=False),
        ),
    ]
