# Generated by Django 2.2.15 on 2020-08-18 22:03

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('volunteers', '0004_volunteer_timezone'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='tasktemplate',
            options={'permissions': (('accept_video_tasks', 'Can accept video tasks'),)},
        ),
        migrations.AddField(
            model_name='task',
            name='required_permission',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='tasktemplate',
            name='required_permission',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
    ]
