{% load static %}
<img src="{% static 'img/1f.svg' %}"/>

<ul>
  <li><strong>Front Desk:</strong> +886 70-1017-2223, registration@debconf.org</li>
  <li><strong>Police:</strong> 110</li>
  <li><strong>Fire/Ambulance:</strong> 119</li>
  <li><strong>Website:</strong> deb.li/dc18</li>
  <li><strong>Wiki:</strong> deb.li/dc18wiki</li>
  <li><strong>Code of Conduct:</strong> deb.li/dccoc</li>
</ul>
<div class="two-col">
  <ul>
    <li><strong>Room X:</strong> 1F 106</li>
    <li><strong>Room Y:</strong> 1F International</li>
    <li><strong>Room Z:</strong> 2F 201</li>
    <li><strong>Room A:</strong> 5F 510</li>
    <li><strong>Room B:</strong> 8F 815</li>
    <li><strong>Noisy Hacklab:</strong> 1F 101</li>
    <li><strong>Silent Hacklab:</strong> 2F 203</li>
    <li><strong>Child Care:</strong> 1F VIP</li>
    <li><strong>Orga Team:</strong>1F VIP</li>
    <li><strong>Video Team:</strong> 7F 705</li>
    <li><strong>Storage:</strong> 7F 724</li>
  </ul>
</div>
