// Spinning Icons
// --------------------------

.#{$fa-css-prefix}-spin {
  -webkit-animation: #{$fa-css-prefix}-spin 2s infinite linear;
          animation: #{$fa-css-prefix}-spin 2s infinite linear;
}

.#{$fa-css-prefix}-pulse {
  -webkit-animation: #{$fa-css-prefix}-spin 1s infinite steps(8);
          animation: #{$fa-css-prefix}-spin 1s infinite steps(8);
}

@-webkit-keyframes #{$fa-css-prefix}-spin {
  0% {
    -webkit-transform: rotate(0deg);
            transform: rotate(0deg);
  }
  100% {
    -webkit-transform: rotate(359deg);
            transform: rotate(359deg);
  }
}

@keyframes #{$fa-css-prefix}-spin {
  0% {
    -webkit-transform: rotate(0deg);
            transform: rotate(0deg);
  }
  100% {
    -webkit-transform: rotate(359deg);
            transform: rotate(359deg);
  }
}
