# Generated by Django 4.2.8 on 2023-12-23 17:48

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("minidebconf", "0004_alter_registration_phone_number"),
    ]

    operations = [
        migrations.AddField(
            model_name="registration",
            name="arranged_accommodation",
            field=models.BooleanField(
                default=False, verbose_name="Conference-arranged accommodation"
            ),
        ),
        migrations.AddField(
            model_name="registration",
            name="arranged_food",
            field=models.BooleanField(
                default=False, verbose_name="Conference-arranged food"
            ),
        ),
    ]
