{% extends "wafer/base.html" %}
{% load i18n %}

{% block content %}
<h1>{% trans 'Registration complete' %}</h1>
<div class="alert alert-success" role="alert">
  {% blocktrans trimmed %}
    Your registration was completed with success.
  {% endblocktrans %}
</div>
<div>
  <p>
    {% blocktrans trimmed %}
      If you need to update any information, you can use the "Update Registration"
      button on your profile page.
    {% endblocktrans %}
  </p>
</div>
<div>
  <a class="btn btn-success" href="/accounts/profile/">{% trans "OK" %}</a>
</div>
{% endblock %}
