# Generated by Django 2.2.27 on 2022-03-16 01:22

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('register', '0012_covid19'),
    ]

    operations = [
        migrations.CreateModel(
            name='Visa',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('country', models.CharField(max_length=2)),
                ('attendee', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='visa', to='register.Attendee')),
            ],
        ),
    ]
