{# Copied the important bits from crispy_forms/templates/bootstrap4/field.html #}
{# and crispy_forms/templates/bootstrap4/layout/checkboxselectmultiple.html #}
<{% if tag %}{{ tag }}{% else %}div{% endif %} id="div_{{ field.auto_id }}" class="form-group{% if wrapper_class %} {{ wrapper_class }}{% endif %}{% if field.css_classes %} {{ field.css_classes }}{% endif %}">
  {% if field.label and form_show_labels %}
     <label for="{{ field.id_for_label }}" class="col-form-label {{ label_class }}{% if field.field.required %} requiredField{% endif %}">
         {{ field.label|safe }}{% if field.field.required %}<span class="asteriskField">*</span>{% endif %}
     </label>
  {% endif %}
  <div class="{% if inline_class %}form-check{% endif %}{% if field_class %} {{ field_class }}{% endif %}"{% if flat_attrs %} {{ flat_attrs|safe }}{% endif %}>
    {% if form_show_errors and field.errors %}
      {% for error in field.errors %}
        <p id="error_{{ forloop.counter }}_{{ field.auto_id }}" class="invalid-feedback d-block"><strong>{{ error }}</strong></p>
      {% endfor %}
    {% endif %}
    {% block field %}
    {% endblock %}
    {% include 'bootstrap4/layout/help_text.html' %}
  </div>
</{% if tag %}{{ tag }}{% else %}div{% endif %}>
