# Generated by Django 4.2.8 on 2023-12-23 20:34

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):
    dependencies = [
        ("minidebconf", "0006_registration_notes_registration_travel_cost_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="registration",
            name="diet",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to="minidebconf.diet",
                verbose_name="Diet",
            ),
        ),
    ]
